#!/bin/sh
kernel="$1"
arch="$2"
patchdir="$3"
config="$4"
[ -z "$MAKE_THREADS" ] && MAKE_THREADS=8

[ -z "$1" -o -z "$2" -o -z "$3" -o -z "$4" ] && \
	{ echo "syntax $0 kerneldir arch patchdir config_file" ; exit 1; }

cd $kernel || exit 1

patches=
[ -e patched ] || patches=$(find $patchdir -name '*.patch' -o -name '*.diff')
for p in $patches ; do
	echo "applying patch $p"
	patch -p1 < "$p" || { echo "error" ; exit 1 ; }
done
touch patched

cp "$config" my.config

echo "XXX make clean"
make mrproper

make V=1 ARCH=$arch allnoconfig HOSTCFLAGS="-D_GNU_SOURCE" KCONFIG_ALLCONFIG=my.config || exit 1

echo "XXX make deps"
make V=1 CC="$CC" HOSTCC="$HOSTCC" ARCH=$arch HOSTCFLAGS=-D_GNU_SOURCE dep || exit 1

echo "XXX compile starts"
make V=1 -j$MAKE_THREADS CC="$CC" ARCH=$arch HOSTCC="$HOSTCC" HOSTCFLAGS=-D_GNU_SOURCE || exit 1

echo "XXX compile finished"
echo your kernel is
find arch/$arch/boot -name bzImage -o -name zImage -o linux.bin

